@@ -1,6 +1,6 @@
 from cannerflow.request import Request
 from cannerflow.saved_query import SavedQuery
-from cannerflow.statement import Statement
+from cannerflow.query import Query
 from cannerflow.file import File
 
 __all__ = ["Workspace"]
@@ -10,12 +10,12 @@ class Workspace(object):
         self,
         endpoint,
         headers,
-        workspaceId,
+        workspace_id,
         replaceLocalhostString
     ):
         self.endpoint = endpoint
         self.headers = headers
-        self.workspaceId = workspaceId
+        self.workspace_id = workspace_id
         request = Request(
             headers=headers,
             endpoint=endpoint
@@ -23,14 +23,19 @@ class Workspace(object):
         self.request = request
         self.saved_query = SavedQuery(
             request=request,
-            workspaceId=workspaceId
-        )
-        self.statement = Statement(
-            request=request,
-            workspaceId=workspaceId
+            workspace_id=workspace_id
         )
         self.file = File(
             request=request,
-            workspaceId=workspaceId,
+            workspace_id=workspace_id,
             replaceLocalhostString=replaceLocalhostString
+        )
+    def gen_query(self, sql, cache_refresh, cache_ttl, data_format):
+        return Query(
+            request=self.request,
+            workspace_id=self.workspace_id,
+            sql=sql,
+            cache_refresh=cache_refresh,
+            cache_ttl=cache_ttl,
+            data_format=data_format
         )
\ No newline at end of file
